@@ -137,7 +137,7 @@ class WaifuAioClient(contextlib.AbstractAsyncContextManager):
             excluded_tags: The tag(s) that you want to exclude
             excluded_files: A list of files that you do not want to get.
             is_nsfw: If False is provided prevent the API to return nsfw files, else if True is provided force it to do
-            so, if 'null' is provided it's search (Default fixed by the API, see the documentation).
+            so, if 'null' is provided it's random (Default fixed by the API, see the documentation).
             many: Get multiples images instead of a single one (see the api docs for the exact number).
             order_by: Order the images according to the value given (see the docs for the accepted values)
             orientation: Choose the images orientation according to the value given (see the docs for the accepted values)
@@ -319,17 +319,21 @@ class WaifuAioClient(contextlib.AbstractAsyncContextManager):
         headers = self._create_headers(**{'User-Agent': self.appname, 'Authorization': f'Bearer {self.token}'})
         return await self._make_request(f"{APIBaseURL}report", 'post', json=params, headers=headers)
 
-    async def tags(self, full=False) -> dict | list[Tag]:
+    async def tags(self, full=False, raw=False) -> dict | list[Tag]:
         """Gets the API endpoints, same as endpoints method but returns a list of Tag (see types.py).
         Returns:
             A list of Tag.
+        Kwargs:
+            full: returns detailed information on the tag
+            raw: returns the raw data from the api
         Raises:
             APIException: If the API response contains an error.
+
         """
         params = self._create_params(full=full)
         headers = self._create_headers(**{'User-Agent': self.appname})
         results = await self._make_request(APIBaseURL + f'tags', 'get', params=params, headers=headers)
-        if not full:
+        if not full or raw:
             return results
         tags = []
         for k, v in results.items():
